# OperationalInsightsData

> see https://aka.ms/autorest

This is the AutoRest configuration file for OperationalInsightsData.

---

## Getting Started

To build the SDK for OperationalInsightsData, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information

These are the global settings for the OperationalInsightsData API.

``` yaml
title: OperationalInsightsDataClient
description: Log Analytics Data Plane Client
add-credentials: true
openapi-type: data-plane
tag: v1
```

### Tag: v1

These settings apply only when `--tag=v1` is specified on the command line.

``` yaml $(tag) == 'v1'
input-file:
- Microsoft.OperationalInsights/stable/v1/OperationalInsights.json
directive:
  - reason: Don't expose the GET endpoint since it's behavior is more limited than POST
    remove-operation: Query_Get
```

``` yaml $(tag) == '20171001'
input-file:
- Microsoft.OperationalInsights/preview/2017-10-01/swagger.json
directive:
  - reason: Rename Query_Post to Query so that we don't get an IQuery interface with 1 operation
    where-operation: Query_Post
    transform: $.operationId = "Query"
```

---

# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-node
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

```yaml $(csharp)
csharp:
  namespace: Microsoft.Azure.OperationalInsights
  output-folder: $(csharp-sdks-folder)/OperationalInsights/DataPlane/OperationalInsights/Generated
  clear-output-folder: true
  payload-flattening-threshold: 3
```

``` yaml $(python)
python-mode: create
python:
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.loganalytics
  package-name: azure-loganalytics
  package-version: 0.1.0
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-loganalytics/azure/loganalytics
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-loganalytics
```

## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  clear-output-folder: true
  namespace: operationalinsights
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: v1
```

### Tag: v1 and go

These settings apply only when `--tag=v1 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag)=='v1' && $(go)
output-folder: $(go-sdk-folder)/services/operationalinsights/v1/operationalinsights
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: false
  namespace: com.microsoft.azure.loganalytics
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/loganalytics/data-plane
  ```